@@ -75,10 +75,17 @@
 #' shinyApp(ui, server)
 #'
 #' }
-chooseSliderSkin <- function(skin = c("Shiny", "Flat", "Modern", "Nice",
-                                      "Simple", "HTML5", "Round", "Square"),
+chooseSliderSkin <- function(skin = c("Shiny", "Flat", "Big", "Modern", "Sharp", "Round", "Square",
+                                      "Nice", "Simple", "HTML5"),
                              color = NULL) {
   skin <- match.arg(arg = skin)
+  if (packageVersion("shiny") > "1.5.0.9000" & skin %in% c("Nice", "Simple", "HTML5")) {
+    warning(paste(
+      "Skin '", skin,
+      "' is deprecated, please see http://ionden.com/a/plugins/ion.rangeSlider/skins.html for available ones."
+    ))
+    skin <- "Flat"
+  }
   cssColor <- NULL
   if (!is.null(color)) {
     stopifnot(length(color) == 1)
@@ -91,7 +98,15 @@ chooseSliderSkin <- function(skin = c("Shiny", "Flat", "Modern", "Nice",
               color
             ),
             if (skin == "Modern")
-              sprintf(".irs-from:after, .irs-to:after, .irs-single:after {border-top-color: %s !important;}", color)
+              sprintf(
+                ".irs-from:after, .irs-to:after, .irs-single:after {border-top-color: %s !important;}",
+                color
+              ),
+            if (skin == "Modern")
+              sprintf(
+                ".irs-from:before, .irs-to:before, .irs-single:before {border-top-color: %s !important;}",
+                color
+              )
           )
         )
       )
