@@ -176,11 +176,17 @@ $.extend(AirPickerInputBinding, {
     $(el).off(".AirPickerInputBinding");
   },
   receiveMessage: function(el, data) {
-    if (data.clear) {
-      $(el)
+    var calendar = $(el)
         .airdatepicker()
-        .data("airdatepicker")
-        .clear();
+        .data("airdatepicker");
+    if (data.clear) {
+      calendar.clear();
+    }
+    if (data.show) {
+      calendar.show();
+    }
+    if (data.hide) {
+      calendar.hide();
     }
     if (data.hasOwnProperty("value")) this.setValue(el, data.value);
 
